@@ -31,7 +31,11 @@ kwt <- function(x, x.by) {
 ## 1. chisq goodness of fit, equal proportions across table cells
 chisq <- function(x, x.by) {
   tab <- table(x, x.by, exclude=NA)
-  return(stats::chisq.test(tab[rowSums(tab)>0,]))
+  if(sum(rowSums(tab)>0)>1) {
+    stats::chisq.test(tab[rowSums(tab)>0,])
+  } else {
+    list(statistic=0, p.value=1, method="Pearson's Chi-squared test")
+  }
 }
 ## 2. Fisher's exact test for prob of as or more extreme table
 fe <- function(x, x.by) {
