@@ -1,4 +1,7 @@
-## ---- load-data----------------------------------------------------------
+## ----echo = FALSE---------------------------------------------------------------------------------
+options(width = 100)
+
+## ---- load-data-----------------------------------------------------------------------------------
 require(arsenal)
 require(knitr)
 require(survival)
@@ -7,16 +10,19 @@ dim(mockstudy)  ##look at how many subjects and variables are in the dataset
 # help(mockstudy) ##learn more about the dataset and variables
 str(mockstudy) ##quick look at the data
 
-## ---- simple1------------------------------------------------------------
+## ---- simple1-------------------------------------------------------------------------------------
 tab1 <- tableby(arm ~ sex + age, data=mockstudy)
 
-## ---- simple-text--------------------------------------------------------
+## ---- simple-text---------------------------------------------------------------------------------
 summary(tab1, text=TRUE)
 
-## ---- simple-markdown, results='asis'------------------------------------
+## ---- simple-markdown, results='asis'-------------------------------------------------------------
 summary(tab1)
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
+as.data.frame(tab1)
+
+## -------------------------------------------------------------------------------------------------
 ## base R frequency example
 tmp <- table(Gender=mockstudy$sex, "Study Arm"=mockstudy$arm)
 tmp
@@ -34,95 +40,95 @@ tapply(mockstudy$age, mockstudy$arm, summary)
 summary(aov(age ~ arm, data=mockstudy))
 
 
-## ---- check-labels-------------------------------------------------------
+## ---- check-labels--------------------------------------------------------------------------------
 ## Look at one variable's label
 attr(mockstudy$age,'label')
 
 ## See all the variables with a label
 unlist(lapply(mockstudy,'attr','label'))
 
-## ---- add-label, results='asis'------------------------------------------
+## ---- add-label, results='asis'-------------------------------------------------------------------
 attr(mockstudy$sex,'label')  <- 'Gender'
 
 tab1 <- tableby(arm ~ sex + age, data=mockstudy)
 summary(tab1)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 mylabels <- list( sex = "SEX", age ="Age, yrs")
 summary(tab1, labelTranslations = mylabels)
 
-## ---- assignlabels-------------------------------------------------------
+## ---- assignlabels--------------------------------------------------------------------------------
 labels(tab1)
 labels(tab1) <- c(arm="Treatment Assignment", age="Baseline Age (yrs)")
 labels(tab1)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tab1)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 mycontrols  <- tableby.control(test=FALSE, total=FALSE,
                                numeric.test="kwt", cat.test="chisq",
                                numeric.stats=c("N", "median", "q1q3"),
                                cat.stats=c("countpct"),
-                               stats.labels=list(N='Count', median='Median', q1q3='Q1,Q3'))                            
+                               stats.labels=list(N='Count', median='Median', q1q3='Q1,Q3'))
 tab2 <- tableby(arm ~ sex + age, data=mockstudy, control=mycontrols)
 summary(tab2)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 tab3 <- tableby(arm ~ sex + age, data=mockstudy, test=FALSE, total=FALSE, 
                 numeric.stats=c("median","q1q3"), numeric.test="kwt")
 summary(tab3)
 
-## ---- testformula--------------------------------------------------------
+## ---- testformula---------------------------------------------------------------------------------
 tab.test <- tableby(arm ~ kwt(age) + anova(bmi) + kwt(ast), data=mockstudy)
 tests(tab.test)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tab.test)
 
-## ---- testsAndStats, results='asis'--------------------------------------
+## ---- testsAndStats, results='asis'---------------------------------------------------------------
 tab.test <- tableby(arm ~ kwt(ast, "Nmiss2","median") + anova(age, "N","mean") +
                     kwt(bmi, "Nmiss","median"), data=mockstudy)
 summary(tab.test)
 
-## ---- nobyvar, results='asis'--------------------------------------------
+## ---- nobyvar, results='asis'---------------------------------------------------------------------
 tab.noby <- tableby(~ bmi + sex + age, data=mockstudy)
 summary(tab.noby)
 
-## ---- results="asis"-----------------------------------------------------
+## ---- results="asis"------------------------------------------------------------------------------
 summary(tab.test) #, pfootnote=TRUE)
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 mockstudy$age.ordnew <- ordered(c("a",NA,as.character(mockstudy$age.ord[-(1:2)])))
 table(mockstudy$age.ord, mockstudy$sex)
 table(mockstudy$age.ordnew, mockstudy$sex)
 class(mockstudy$age.ord)
 
-## ---- results="asis"-----------------------------------------------------
+## ---- results="asis"------------------------------------------------------------------------------
 summary(tableby(sex ~ age.ordnew, data = mockstudy)) #, pfootnote = TRUE)
 summary(tableby(sex ~ kwt(age.ord), data = mockstudy)) #) #, pfootnote = TRUE)
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 survfit(Surv(fu.time, fu.stat)~sex, data=mockstudy)
 survdiff(Surv(fu.time, fu.stat)~sex, data=mockstudy)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tableby(sex ~ Surv(fu.time, fu.stat), data=mockstudy))
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 summary(survfit(Surv(fu.time/365.25, fu.stat)~sex, data=mockstudy), times=1:5)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tableby(sex ~ Surv(fu.time/365.25, fu.stat), data=mockstudy, times=1:5, surv.stats=c("NeventsSurv","NriskSurv")))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 set.seed(100)
 N <- nrow(mockstudy)
 mockstudy$dtentry <- mdy.Date(month=sample(1:12,N,replace=T), day=sample(1:29,N,replace=T), 
                               year=sample(2005:2009,N,replace=T))
 summary(tableby(sex ~ dtentry, data=mockstudy))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 ## create a vector specifying the variable names
 myvars <- names(mockstudy)
 
@@ -137,7 +143,7 @@ as.formula(paste('arm ~ ', RHS))
 ## use the formula in the tableby function
 summary(tableby(as.formula(paste('arm ~', RHS)), data=mockstudy))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 ## The formulize function does the paste and as.formula steps
 tmp <- formulize('arm',myvars[8:10])
 tmp
@@ -148,51 +154,51 @@ tmp2 <- formulize('arm',c('ps','hgb^2','bmi'))
 ## use the formula in the tableby function
 summary(tableby(tmp, data=mockstudy))
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 newdata <- subset(mockstudy, subset=age>50 & arm=='F: FOLFOX', select = c(sex,ps:bmi))
 dim(mockstudy)
 table(mockstudy$arm)
 dim(newdata)
 names(newdata)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tableby(sex ~ ., data=newdata))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tableby(sex ~ ps + hgb + bmi, subset=age>50 & arm=="F: FOLFOX", data=mockstudy))
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 ## create a variable combining the levels of mdquality.s and sex
 with(mockstudy, table(interaction(mdquality.s,sex)))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tableby(arm ~ interaction(mdquality.s,sex), data=mockstudy))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 ## create a new grouping variable with combined levels of arm and sex
 summary(tableby(interaction(mdquality.s, sex) ~  age + bmi, data=mockstudy, subset=arm=="F: FOLFOX"))
 
-## ---- maketrans, results='asis'------------------------------------------
+## ---- maketrans, results='asis'-------------------------------------------------------------------
 trans <- tableby(arm ~ I(age/10) + log(bmi) + factor(mdquality.s, levels=0:1, labels=c('N','Y')),
                  data=mockstudy)
 summary(trans)
 
-## ---- assignlabels2------------------------------------------------------
+## ---- assignlabels2-------------------------------------------------------------------------------
 labels(trans)
 labels(trans)[2:4] <- c('Age per 10 yrs', 'log(BMI)', 'MD Quality')
 labels(trans)
 
-## ---- transsummary, results='asis'---------------------------------------
+## ---- transsummary, results='asis'----------------------------------------------------------------
 summary(trans)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 class(mockstudy$mdquality.s)
 summary(tableby(arm~mdquality.s, data=mockstudy))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tableby(arm ~ chisq(mdquality.s, "Nmiss","countpct"), data=mockstudy))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 mytab <- tableby(arm ~ sex + alk.phos + age, data=mockstudy)
 mytab2 <- mytab[c('age','sex','alk.phos')]
 summary(mytab2)
@@ -200,7 +206,7 @@ summary(mytab[c('age','sex')], nsmall = 2)
 summary(mytab[c(3,1)], nsmall = 3)
 
 
-## ---- results="asis"-----------------------------------------------------
+## ---- results="asis"------------------------------------------------------------------------------
 ## demographics
 tab1 <- tableby(arm ~ sex + age, data=mockstudy,
                 control=tableby.control(numeric.stats=c("Nmiss","meansd"), total=FALSE))
@@ -215,15 +221,15 @@ class(tab12)
 names(tab12$x)
 summary(tab12) #, pfootnote=TRUE)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 t1 <- tableby(arm ~ sex + age, data=mockstudy)
 summary(t1, title='Demographics')
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 ## look at how many missing values there are for each variable
 apply(is.na(mockstudy),2,sum)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 ## Show how many subjects have each variable (non-missing)
 summary(tableby(sex ~ ast + age, data=mockstudy,
                 control=tableby.control(numeric.stats=c("N","median"), total=FALSE)))
@@ -240,10 +246,10 @@ summary(tableby(sex ~ ast + age, data=mockstudy,
 summary(tableby(sex ~ ast + age, data=mockstudy, 
                 control=tableby.control(numeric.stats=c("mean"),total=FALSE)))
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 summary(tableby(arm ~ sex + age + fu.time, data=mockstudy), digits=4, digits.test=2, nsmall.pct=1)
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 format(pi, digits=1)
 format(pi, digits=3)
 format(pi, digits=4)
@@ -252,7 +258,7 @@ format(pi*100, digits=4)
 format(pi*100, nsmall=4)
 format(pi*100, nsmall=2, digits=4)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 myfunc <- function(x, weights=rep(1,length(x)), ...){
   mean(x, trim=.1, ...)
 }
@@ -262,7 +268,7 @@ summary(tableby(sex ~ hgb, data=mockstudy,
                     stats.labels=list(Nmiss='Missing values', myfunc="Trimmed Mean, 10%"))))
 
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 ##create fake group that is not balanced by age/sex 
 set.seed(200)
 mockstudy$fake_arm <- ifelse(mockstudy$age>60 & mockstudy$sex=='Female',sample(c('A','B'),replace=T, prob=c(.2,.8)),
@@ -284,25 +290,25 @@ mockstudy$wts <- gpwts[index]
 ## show weights by treatment arm group
 tapply(mockstudy$wts,mockstudy$fake_arm, summary)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 orig <- tableby(fake_arm ~ age + sex + Surv(fu.time/365, fu.stat), data=mockstudy, test=FALSE)
 summary(orig, title='No Case Weights used')
 tab1 <- tableby(fake_arm ~ age + sex + Surv(fu.time/365, fu.stat), data=mockstudy, weights=wts)
 summary(tab1, title='Case Weights used')
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 mypval <- data.frame(variable=c('age','sex','Surv(fu.time/365, fu.stat)'), 
                      adj.pvalue=c(.953,.811,.01), 
                      method=c('Age/Sex adjusted model results'))
 tab2 <- modpval.tableby(tab1, mypval, use.pname=TRUE)
 summary(tab2, title='Case Weights used, p-values added') #, pfootnote=TRUE)
 
-## ---- results='asis'-----------------------------------------------------
+## ---- results='asis'------------------------------------------------------------------------------
 levels(mockstudy$sex)
 table2 <- tableby(arm~sex + factor(mdquality.s), data=mockstudy, cat.simplify=TRUE)
 summary(table2, labelTranslations=c(sex="Female", "factor(mdquality.s)"="MD Quality"))
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 tab1 <- tableby(arm~sex+age, data=mockstudy)
 summary(tab1, text=T)
 
@@ -311,17 +317,17 @@ tmp
 
 # write.csv(tmp, '/my/path/here/mymodel.csv')
 
-## ------------------------------------------------------------------------
-## write to an HTML document
-tab1 <- tableby(arm ~ sex + age, data=mockstudy)
-# write2html(tab1, "~/ibm/trash.html")
+## ----eval = FALSE---------------------------------------------------------------------------------
+#  ## write to an HTML document
+#  tab1 <- tableby(arm ~ sex + age, data=mockstudy)
+#  write2html(tab1, "~/trash.html")
+#  
+#  ## write to a Word document
+#  write2word(tab1, "~/trash.doc", title="My table in Word")
 
-## write to a Word document
-# write2word(tab1, "~/ibm/trash.doc", title="My table in Word")
-
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 args(tableby.control)
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
 args(arsenal:::summary.tableby)
 
